Documentation
¶
Index ¶
- type XMLElement
- func (element *XMLElement) GetAllNodes(xpath string) []XMLElement
- func (element *XMLElement) GetNode(xpath string) XMLElement
- func (element *XMLElement) GetNodes(xpath string) []XMLElement
- func (element *XMLElement) GetValue(xpath string) string
- func (element *XMLElement) GetValueDeep(xpath string) string
- func (element *XMLElement) GetValueF64(xpath string) float64
- func (element *XMLElement) GetValueF64Deep(xpath string) float64
- func (element *XMLElement) GetValueInt(xpath string) int
- func (element *XMLElement) GetValueIntDeep(xpath string) int
- type XMLParser
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type XMLElement ¶
type XMLElement struct {
Name string
Attrs map[string]string
InnerText string
Childs map[string][]XMLElement
Err error
// contains filtered or unexported fields
}
func (*XMLElement) GetAllNodes ¶ added in v1.1.5
func (element *XMLElement) GetAllNodes(xpath string) []XMLElement
func (*XMLElement) GetNode ¶ added in v1.1.5
func (element *XMLElement) GetNode(xpath string) XMLElement
func (*XMLElement) GetNodes ¶ added in v1.1.5
func (element *XMLElement) GetNodes(xpath string) []XMLElement
func (*XMLElement) GetValue ¶ added in v1.1.5
func (element *XMLElement) GetValue(xpath string) string
func (*XMLElement) GetValueDeep ¶ added in v1.1.5
func (element *XMLElement) GetValueDeep(xpath string) string
func (*XMLElement) GetValueF64 ¶ added in v1.1.5
func (element *XMLElement) GetValueF64(xpath string) float64
func (*XMLElement) GetValueF64Deep ¶ added in v1.1.5
func (element *XMLElement) GetValueF64Deep(xpath string) float64
func (*XMLElement) GetValueInt ¶ added in v1.1.5
func (element *XMLElement) GetValueInt(xpath string) int
func (*XMLElement) GetValueIntDeep ¶ added in v1.1.5
func (element *XMLElement) GetValueIntDeep(xpath string) int
type XMLParser ¶
type XMLParser struct {
TotalReadSize uint64
// contains filtered or unexported fields
}
func NewXMLParser ¶ added in v1.1.1
func (*XMLParser) EnableXpath ¶ added in v1.1.5
func (*XMLParser) ParseAttributesOnly ¶ added in v1.1.5
func (*XMLParser) SkipElements ¶ added in v1.1.0
func (*XMLParser) SkipOuterElements ¶ added in v1.1.5
by default skip elements works for stream elements childs if this method called parser skip also outer elements
func (*XMLParser) Stream ¶ added in v1.1.0
func (x *XMLParser) Stream() chan *XMLElement
Click to show internal directories.
Click to hide internal directories.